@@ -1,4 +1,5 @@
 import os
+import pkg_resources
 import sys
 
 from importlib import resources
@@ -26,7 +27,7 @@ def download_lato_font(verbose=False):
     if verbose:
         print("... extracting lato.zip contents to mpl-data/fonts ...")
 
-    font_file = resources.path("apol_dataviz", "fonts/lato.zip")
+    font_file = pkg_resources.resource_filename(__name__, "fonts/lato.zip")
 
     with ZipFile(font_file, "r") as zip:
         zip.extractall(mpl_fonts)
